@@ -6,8 +6,7 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 
-// XML Type [[Descendants]]
-START("9.1.1.8 - XML [[Descendants]]");
+START("9.2.1.7 XMLList [[DeepCopy]]");
 
 var actual = 'Test not implemented';
 var expect = 'PASS';
