@@ -1,11 +1,12 @@
+// |reftest| pref(javascript.options.xml.content,true)
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 467495;
-var summary = 'TCF_FUN_CLOSURE_VS_VAR is necessary';
+var BUGNUMBER = 352870;
+var summary = 'Do not assert for crazy huge testcases';
 var actual = '';
 var expect = '';
 
@@ -19,26 +20,18 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
-
-  function f(x)
+ 
+  expect = /TypeError: .+\.g (has no properties|is undefined)/;
+  actual = '';
+  try
   {
-    var y = 1;
-    if (Math)
-      function x() { }
-    if (Math)
-      function y() { }
-    return [x, y];
+    switch(4) { case [(let (y = [].j(5)) ({}))
+                      for (p in ([1,2,3,4].g).v({},((w).y(z, <x/>))))]: }  }
+  catch(ex)
+  {
+    actual = ex + '';
   }
-
-  var r = f(0);
-
-  if (typeof(r[0]) != "function")
-    actual += "Bad r[0]";
-
-  if (typeof(r[1]) != "function")
-    throw "Bad r[1]";
-
-  reportCompare(expect, actual, summary);
+  reportMatch(expect, actual, summary);
 
   exitFunc ('test');
 }
