@@ -1,15 +1,15 @@
-// |reftest| pref(javascript.options.xml.content,true)
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 351102;
-var summary = 'try/catch-guard/finally GC issues';
+var BUGNUMBER = 452498;
+var summary = 'TM: upvar2 regression tests';
 var actual = '';
 var expect = '';
 
+//-------  Comment #193  From  Gary Kwong
 
 //-----------------------------------------------------------------------------
 test();
@@ -20,16 +20,15 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
- 
-  var f;
-  try
-  {
-    try { @foo } catch([] if gc()) { }
-  }
-  catch(ex)
-  {
-  }
-  reportCompare(expect, actual, summary + ': 4');
+
+// Assertion failure: afunbox->parent, at ../jsparse.cpp:1912
+
+  this.x = undefined;
+  this.watch("x", Function);
+  NaN = uneval({ get \u3056 (){ return undefined } });
+  x+=NaN;
+
+  reportCompare(expect, actual, summary);
 
   exitFunc ('test');
 }
